===============
Release History
===============

v0.1.1 (2018-10-29)
----------------------------

This is a maintenance release

* Fix error on python 2.7
* Travis integration
* Documentation integration

v0.1.0 (2018-09-21)
----------------------------

This initial release is a split from DIPY. It contains:

* from ``dipy.viz.actors`` to ``fury.actors``
* from ``dipy.viz.window`` to ``fury.window``
* from ``dipy.viz.ui`` to ``fury.ui``
* from ``dipy.viz.widget`` to ``fury.widget``
* from ``dipy.viz.interactor`` to ``fury.interactor``
* from ``dipy.viz.colormap`` to ``fury.colormap``
* from ``dipy.viz.utils`` to ``fury.utils``

